package
Version:
v2.1.3
Opens a new window with list of versions in this module.
Published: Jan 26, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 8
Opens a new window with list of known importers.
Documentation
¶
type Database interface {
GetInstance() *database
Connect()
Disconnect()
Pool() *pgxpool.Pool
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.